@@ -24,7 +24,7 @@ from .utils import (
 )
 @proxy_method_directly("detach", "fileno", "readable")
 @proxy_property_directly(
-    "buffer", "closed", "encoding", "errors", "line_buffering", "newlines"
+    "buffer", "closed", "encoding", "errors", "line_buffering", "newlines", "name", "mode"
 )
 class AsyncTextIOWrapper(AsyncBase):
     """The asyncio executor version of io.TextIOWrapper."""
